@@ -2,7 +2,7 @@
 """Top-level package for DeepForest."""
 __author__ = """Ben Weinstein"""
 __email__ = 'ben.weinstein@weecology.org'
-__version__ = '0.3.7'
+__version__ = '1.1.1'
 
 import os
 
@@ -10,4 +10,5 @@ _ROOT = os.path.abspath(os.path.dirname(__file__))
 
 
 def get_data(path):
-    return os.path.join(_ROOT, 'data', path)
+    """helper function to get package sample data"""
+    return os.path.normpath(os.path.join(_ROOT, 'data', path))
